          * [Synchronizing Subscriptions Across Related Fact Sheets (Subscription Inheritance)](https://help.sap.com/docs/leanix/ea/synchronizing-subscriptions-across-related-fact-sheets-subscription-inheritance)
          * [Propagating Business Context Relations to Parent Applications (Relation Inheritance)](https://help.sap.com/docs/leanix/ea/propagating-business-context-relations-to-parent-applications-relation-inheritance)
          * [Breaking Application Quality Seals when Initiatives Reach End of Life](https://help.sap.com/docs/leanix/ea/breaking-application-quality-seals-when-initiatives-reach-end-of-life)
          * [Validating the Plan Lifecycle Phase](https://help.sap.com/docs/leanix/ea/validating-plan-lifecycle-phase)
          * [Updating a Lifecycle Phase and Approving the Quality Seal](https://help.sap.com/docs/leanix/ea/updating-lifecycle-phase-and-approving-quality-seal)
          * [Syncing Tags with the Current Lifecycle Phases](https://help.sap.com/docs/leanix/ea/syncing-tags-with-current-lifecycle-phases)
          * [Updating Lifecycle Phases](https://help.sap.com/docs/leanix/ea/updating-lifecycle-phases)
        * [Creating an Automation with a Webhook Action](https://help.sap.com/docs/leanix/ea/automations-webhooks)
      * [Calculations](https://help.sap.com/docs/leanix/ea/calculations)
        * [Calculation Examples](https://help.sap.com/docs/leanix/ea/calculation-examples)
      * [Calculations and Automations: When to Use Each Feature](https://help.sap.com/docs/leanix/ea/calculations-and-automations-when-to-use-each-feature)
      * [Export](https://help.sap.com/docs/leanix/ea/export)
      * [KPIs](https://help.sap.com/docs/leanix/ea/kpis)
        * [Configuring KPIs](https://help.sap.com/docs/leanix/ea/configuring-kpis)
      * [Managed Code](https://help.sap.com/docs/leanix/ea/managed-code)
      * [Metrics](https://help.sap.com/docs/leanix/ea/metrics)
      * [Notifications Center](https://help.sap.com/docs/leanix/ea/notifications-center)
        * [Configuring the E-Mail Channel](https://help.sap.com/docs/leanix/ea/configuring-e-mail-channel)
          * [Setting Up a Microsoft Exchange Online Mailbox for Email Notifications](https://help.sap.com/docs/leanix/ea/setting-up-microsoft-exchange-online-mailbox-for-email-notifications)
          * [Setting Up a Custom SMTP Server for Email Notifications](https://help.sap.com/docs/leanix/ea/setting-up-custom-smtp-server-for-email-notifications)
        * [Configuring the Microsoft Teams Channel](https://help.sap.com/docs/leanix/ea/configuring-microsoft-teams-channel)
      * [Portals](https://help.sap.com/docs/leanix/ea/portals)
        * [Portal FAQs](https://help.sap.com/docs/leanix/ea/portal-faqs)
        * [Portal: Parameterized Links](https://help.sap.com/docs/leanix/ea/portal-parameterized-links)
      * [Downloading Reports from the SAP LeanIX Store](https://help.sap.com/docs/leanix/ea/download-reports)
      * [To-Dos (Administration)](https://help.sap.com/docs/leanix/ea/to-dos-administration)
      * [Workspace Views Configuration](https://help.sap.com/docs/leanix/ea/workspace-views-configuration)
  * [User and Access Management](https://help.sap.com/docs/leanix/ea/user-and-access-management)
    * [Managing Users](https://help.sap.com/docs/leanix/ea/managing-users)
      * [Users Overview](https://help.sap.com/docs/leanix/ea/users-overview)
      * [User Roles and Permissions](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions)
      * [Authorization Model](https://help.sap.com/docs/leanix/ea/authorization-model)
      * [PII Change Audit Report](https://help.sap.com/docs/leanix/ea/pii-change-audit-report)
    * [Single Sign-On (SSO)](https://help.sap.com/docs/leanix/ea/single-sign-on-sso)
      * [SSO Configuration Process](https://help.sap.com/docs/leanix/ea/sso-configuration-process)
      * [Migration to the Self-Service SSO Configuration](https://help.sap.com/docs/leanix/ea/migration-to-self-service-sso-configuration)
      * [Configuring SSO with Okta](https://help.sap.com/docs/leanix/ea/configuring-sso-with-okta)
      * [Configuring SSO with Microsoft Entra ID](https://help.sap.com/docs/leanix/ea/configuring-sso-with-microsoft-entra-id)
      * [Configuring SSO with SAP Cloud Identity Services - Identity Authentication Service (IAS)](https://help.sap.com/docs/leanix/ea/configuring-sso-with-sap-cloud-identity-services-identity-authentication-service-ias)
      * [Configuring SSO with PingOne](https://help.sap.com/docs/leanix/ea/configuring-sso-with-pingone)
      * [Configuring SSO with OneLogin](https://help.sap.com/docs/leanix/ea/configuring-sso-with-onelogin)
      * [Configuring SSO with Active Directory Federation Services](https://help.sap.com/docs/leanix/ea/configuring-sso-with-active-directory-federation-services)
    * [SCIM Provisioning](https://help.sap.com/docs/leanix/ea/scim-provisioning)
      * [Access Tokens Required for SCIM](https://help.sap.com/docs/leanix/ea/access-tokens-required-for-scim)
      * [Configuring SCIM in Okta](https://help.sap.com/docs/leanix/ea/configuring-scim-in-okta)
      * [Configuring SCIM in Microsoft Entra ID](https://help.sap.com/docs/leanix/ea/configuring-scim-in-microsoft-entra-id)
    * [Virtual Workspaces](https://help.sap.com/docs/leanix/ea/virtual-workspaces)
      * [Virtual Workspaces Configuration](https://help.sap.com/docs/leanix/ea/virtual-workspaces-configuration)
    * [Access to SAP for Me](https://help.sap.com/docs/leanix/ea/access-to-sap-for-me)
      * [Setting Up Your Organization's S-User Administrator](https://help.sap.com/docs/leanix/ea/setting-up-your-organization-s-s-user-administrator)
      * [Creating and Managing S-Users in SAP For Me](https://help.sap.com/docs/leanix/ea/creating-and-managing-s-users-in-sap-for-me)
  * [Discovery and Integrations](https://help.sap.com/docs/leanix/ea/discovery-and-integrations)
    * [Reference Catalog](https://help.sap.com/docs/leanix/ea/reference-catalog)
      * [Business Capabilities in the Reference Catalog](https://help.sap.com/docs/leanix/ea/business-capabilities-in-reference-catalog)
      * [Applications in the Reference Catalog](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog)
      * [IT Components in the Reference Catalog](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog)
      * [Tech Categories in the Reference Catalog](https://help.sap.com/docs/leanix/ea/tech-categories-in-reference-catalog)
        * [Migrating to the TBM Taxonomy Version 5.0.1 for Tech Categories](https://help.sap.com/docs/leanix/ea/migrating-to-tbm-taxonomy-version-5-0-1-for-tech-categories)
      * [Reference Catalog: Best Practices](https://help.sap.com/docs/leanix/ea/reference-catalog-best-practices)
      * [Reference Catalog: Fact Sheet Naming Conventions](https://help.sap.com/docs/leanix/ea/reference-catalog-fact-sheet-naming-conventions)
      * [Reference Catalog: Provider Tiers, Response Times, and FAQs](https://help.sap.com/docs/leanix/ea/reference-catalog-provider-tiers-response-times-and-faqs)
    * [SaaS Discovery](https://help.sap.com/docs/leanix/ea/saas-discovery)
      * [SaaS Discovery Inbox](https://help.sap.com/docs/leanix/ea/saas-discovery-inbox)
      * [Microsoft Defender for Cloud Apps (MDCA) Integration for SaaS Discovery](https://help.sap.com/docs/leanix/ea/microsoft-defender-for-cloud-apps-mdca-integration-for-saas-discovery)
      * [Microsoft Entra ID Integration for SaaS Discovery](https://help.sap.com/docs/leanix/ea/microsoft-entra-id-integration-for-saas-discovery)
      * [Netskope Integration for SaaS Discovery](https://help.sap.com/docs/leanix/ea/netskope-integration-for-saas-discovery)
      * [Okta Integration for SaaS Discovery](https://help.sap.com/docs/leanix/ea/okta-integration-for-saas-discovery)
      * [Zscaler Integration for SaaS Discovery](https://help.sap.com/docs/leanix/ea/zscaler-integration-for-saas-discovery)
      * [WalkMe Integration for SaaS Discovery](https://help.sap.com/docs/leanix/ea/walkme-integration-for-saas-discovery)
    * [Self-Built Software Discovery](https://help.sap.com/docs/leanix/ea/self-built-software-discovery)
      * [Workspace Setup for Self-Built Software Discovery](https://help.sap.com/docs/leanix/ea/workspace-setup-for-self-built-software-discovery)
      * [GitHub Enterprise Integration](https://help.sap.com/docs/leanix/ea/github-enterprise-integration)
        * [Setting Up the GitHub Enterprise Integration](https://help.sap.com/docs/leanix/ea/setting-up-github-enterprise-integration)
        * [GitHub App Permissions](https://help.sap.com/docs/leanix/ea/github-app-permissions)
        * [Code for Deploying the SAP LeanIX GitHub Agent](https://help.sap.com/docs/leanix/ea/code-for-deploying-sap-leanix-github-agent)
        * [SBOM Discovery from Build Artifacts](https://help.sap.com/docs/leanix/ea/sbom-discovery-from-build-artifacts)
      * [Microservice Discovery in Your CI/CD Pipeline](https://help.sap.com/docs/leanix/ea/microservice-discovery-in-your-ci-cd-pipeline)
        * [Configuring Your CI/CD Pipeline](https://help.sap.com/docs/leanix/ea/configuring-your-ci-cd-pipeline)
      * [Manifest File and Schema](https://help.sap.com/docs/leanix/ea/manifest-file-and-schema)
      * [Software Bill of Materials (SBOM)](https://help.sap.com/docs/leanix/ea/software-bill-of-materials-sbom)
        * [Generating SBOMs](https://help.sap.com/docs/leanix/ea/generating-sboms)
        * [SBOM Explorer](https://help.sap.com/docs/leanix/ea/sbom-explorer)
        * [Retrieving SBOM Library Components for Business Applications](https://help.sap.com/docs/leanix/ea/retrieving-sbom-library-components-for-business-applications)
      * [Tech Stack Discovery from SBOMs](https://help.sap.com/docs/leanix/ea/tech-stack-discovery-from-sboms)
        * [Using the MCP Server for Tech Stack Management](https://help.sap.com/docs/leanix/ea/using-mcp-server-for-tech-stack-management)
    * [SAP Discovery](https://help.sap.com/docs/leanix/ea/sap-discovery)
      * [SAP Cloud ALM Integration for SAP Discovery](https://help.sap.com/docs/leanix/ea/sap-discovery-cloud-alm)
        * [Configuring the SAP Cloud ALM Integration](https://help.sap.com/docs/leanix/ea/sap-discovery-configuring-cloud-alm)
        * [Enabling Discovered Flows](https://help.sap.com/docs/leanix/ea/enabling-discovered-flows)
      * [SAP Build Integration for SAP Discovery](https://help.sap.com/docs/leanix/ea/configuring-sap-build-integration)
      * [SAP BTP, Cloud Foundry Integration for SAP Discovery](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration)
        * [Configuring SAP BTP, Cloud Foundry Integration Using Trusted Certificate Authentication](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration-using-trusted-certificate-authentication)
      * [SAP Discovery Inbox](https://help.sap.com/docs/leanix/ea/sap-landscape-discovery-inbox)
    * [AI Agent Discovery](https://help.sap.com/docs/leanix/ea/ai-agent-discovery)
      * [Uploading AI Agents Through the API](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-using-api)
      * [Discovering AI Agents from Microsoft Entra ID](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-microsoft-entra-id)
      * [Discovering AI Agents from Google Agent Engine](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-google-agent-engine)
      * [Discovering SAP AI Agents](https://help.sap.com/docs/leanix/ea/discovering-sap-ai-agents)
      * [Discovering MCP Servers from Microsoft Azure API Center](https://help.sap.com/docs/leanix/ea/discovering-mcp-servers-from-microsoft-azure-api-center)
      * [Discovering AI Agents from Amazon Bedrock](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-from-amazon-bedrock)
      * [AI Agent Discovery Inbox](https://help.sap.com/docs/leanix/ea/ai-agent-discovery-inbox)
    * [SAP Cloud ALM Integration For Managing Projects](https://help.sap.com/docs/leanix/ea/sap-cloud-alm-integration-for-managing-projects)
      * [Configuring SAP Cloud ALM Integration For Managing Projects](https://help.sap.com/docs/leanix/ea/configuring-sap-cloud-alm-integration-for-managing-projects)
      * [Synchronizing Projects Between SAP Cloud ALM and SAP LeanIX](https://help.sap.com/docs/leanix/ea/synchronizing-projects-between-sap-cloud-alm-and-sap-leanix)
    * [SAP Signavio Integration](https://help.sap.com/docs/leanix/ea/sap-signavio-integration)
      * [Configuring the Integration](https://help.sap.com/docs/leanix/ea/configuring-integration)
      * [Mapping SAP Signavio Processes to Fact Sheets](https://help.sap.com/docs/leanix/ea/mapping-sap-signavio-processes-to-fact-sheets)
      * [Mapping Fact Sheets and Dictionary Items](https://help.sap.com/docs/leanix/ea/mapping-fact-sheets-and-dictionary-items)
      * [Synchronizing Process Variants](https://help.sap.com/docs/leanix/ea/synchronizing-process-variants)
      * [Best Practices and Tutorials](https://help.sap.com/docs/leanix/ea/best-practices-and-tutorials)
      * [Advanced Configuration](https://help.sap.com/docs/leanix/ea/sap-signavio-advanced-configuration)
    * [ServiceNow Integration](https://help.sap.com/docs/leanix/ea/servicenow-integration)
      * [Setup in ServiceNow](https://help.sap.com/docs/leanix/ea/setup-in-servicenow)
      * [Setup in SAP LeanIX](https://help.sap.com/docs/leanix/ea/setup-in-sap-leanix)
        * [Aggregation and Linkage of Software Records](https://help.sap.com/docs/leanix/ea/aggregation-and-linkage-of-software-records)
        * [Fact Sheet Mapping Between ServiceNow and SAP LeanIX](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-servicenow-and-sap-leanix)
        * [Matching Rules](https://help.sap.com/docs/leanix/ea/matching-rules)
        * [Relation Mapping Between ServiceNow and SAP LeanIX](https://help.sap.com/docs/leanix/ea/relation-mapping-between-servicenow-and-sap-leanix)
        * [Relations Between Applications and Hardware/Software Items](https://help.sap.com/docs/leanix/ea/relations-between-applications-and-hardware-software-items)
      * [ServiceNow Integration: Advanced Configuration](https://help.sap.com/docs/leanix/ea/servicenow-advanced-configuration)
      * [ServiceNow Integration FAQs](https://help.sap.com/docs/leanix/ea/servicenow-integration-faqs)
    * [Jira Service Management Integration](https://help.sap.com/docs/leanix/ea/jira-service-management-integration)
      * [Configuring the Integration with Jira Service Management](https://help.sap.com/docs/leanix/ea/configuring-integration-with-jira-service-management)
      * [Fact Sheet Mapping Between Jira Service Management and SAP LeanIX](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-jira-service-management-and-sap-leanix)
      * [Relation Mapping Between Jira Service Management and SAP LeanIX](https://help.sap.com/docs/leanix/ea/relation-mapping-between-jira-service-management-and-sap-leanix)
    * [Apptio Integration](https://help.sap.com/docs/leanix/ea/apptio-integration)
      * [Apptio Technical Overview](https://help.sap.com/docs/leanix/ea/apptio-technical-overview)
      * [Setup in Apptio](https://help.sap.com/docs/leanix/ea/setup-in-apptio)
      * [Configuration of the Apptio Connector](https://help.sap.com/docs/leanix/ea/configuration-of-apptio-connector)
    * [Collibra Integration](https://help.sap.com/docs/leanix/ea/collibra-integration)
      * [Configuring Collibra Integration](https://help.sap.com/docs/leanix/ea/configuring-collibra-integration)
      * [Conceptual Data Layer Mapping from Collibra to SAP LeanIX](https://help.sap.com/docs/leanix/ea/conceptual-data-layer-mapping-from-collibra-to-sap-leanix)
      * [Fact Sheet Mapping from SAP LeanIX to Collibra](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-from-sap-leanix-to-collibra)
      * [Relation Mapping from SAP LeanIX to Collibra](https://help.sap.com/docs/leanix/ea/relation-mapping-from-sap-leanix-to-collibra)
      * [Supported Field Types for Conceptual Data Layer Mapping](https://help.sap.com/docs/leanix/ea/supported-field-types-for-conceptual-data-layer-mapping)
      * [Supported Field Types for Fact Sheet Mapping](https://help.sap.com/docs/leanix/ea/supported-field-types-for-fact-sheet-mapping)
    * [Confluence Integration](https://help.sap.com/docs/leanix/ea/confluence-integration)
    * [Jira Integration](https://help.sap.com/docs/leanix/ea/jira-integration)
      * [Setting Up the Jira Integration](https://help.sap.com/docs/leanix/ea/setting-up-jira-cloud-projects-integration)
      * [Importing, Exporting, and Linking Fact Sheets and Jira Work Items](https://help.sap.com/docs/leanix/ea/creating-and-linking-fact-sheets-and-jira-issues)
    * [Jira Marketplace App](https://help.sap.com/docs/leanix/ea/jira-software-integration)
    * [SAP LeanIX App for Microsoft Teams](https://help.sap.com/docs/leanix/ea/sap-leanix-app-for-microsoft-teams)
    * [OData Integration](https://help.sap.com/docs/leanix/ea/odata-integration)
      * [Setting Up the OData Integration with Business Intelligence Tools](https://help.sap.com/docs/leanix/ea/setting-up-odata-integration-with-business-intelligence-tools)
      * [OData Integration Update: Translation Corrections (May 26, 2025)](https://help.sap.com/docs/leanix/ea/odata-integration-update)
    * [LeanIX Adapter for SAP Integration Suite](https://help.sap.com/docs/leanix/ea/leanix-adapter-for-sap-integration-suite)
    * [Synchronization Logging](https://help.sap.com/docs/leanix/ea/synchronization-logging)
  * [Additional Products](https://help.sap.com/docs/leanix/ea/additional-products)
    * [SAP LeanIX Technology Risk and Compliance](https://help.sap.com/docs/leanix/ea/sap-leanix-technology-risk-and-compliance)
      * [Getting Started: Building Your IT Component Inventory](https://help.sap.com/docs/leanix/ea/getting-started-building-your-it-component-inventory)
      * [Obsolescence Risk Management Capabilities](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-capabilities)
        * [Technology Obsolescence Risk Statuses and Views in Reports](https://help.sap.com/docs/leanix/ea/technology-obsolescence-risk-statuses-and-views-in-reports)
        * [Obsolescence Risk Management Dashboard](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-dashboard)
        * [Tutorial: Managing IT Risks Associated with Data Center and Server Locations](https://help.sap.com/docs/leanix/ea/tutorial-managing-it-risks-associated-with-data-center-and-server-locations)
      * [Technology Standards Management Capabilities](https://help.sap.com/docs/leanix/ea/technology-standards-management-capabilities)
    * [SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/sap-leanix-architecture-and-road-map-planning)
      * [Getting Started with SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/getting-started-with-sap-leanix-architecture-and-road-map-planning)
      * [Architecture Decisions](https://help.sap.com/docs/leanix/ea/architecture-decisions)
        * [Architecture Decision Templates](https://help.sap.com/docs/leanix/ea/architecture-decision-templates)
      * [Milestones](https://help.sap.com/docs/leanix/ea/milestones)
      * [Transformations](https://help.sap.com/docs/leanix/ea/transformations)
        * [Transformations Explorer](https://help.sap.com/docs/leanix/ea/transformations-explorer)
        * [Importing and Exporting Transformations via Excel File](https://help.sap.com/docs/leanix/ea/importing-and-exporting-transformations-via-excel-file)
        * [Creating Custom Transformation Templates](https://help.sap.com/docs/leanix/ea/creating-custom-transformation-templates)
        * [Planning Transformations for SAP Solutions](https://help.sap.com/docs/leanix/ea/planning-transformations-for-sap-solutions)
      * [Impacts](https://help.sap.com/docs/leanix/ea/impacts)
        * [Scheduled Changes](https://help.sap.com/docs/leanix/ea/scheduled-changes)
      * [Reports and Roadmaps](https://help.sap.com/docs/leanix/ea/reports-and-roadmaps)
      * [Transition from Transformation Items/Project Fact Sheet to Initiative](https://help.sap.com/docs/leanix/ea/transition-from-transformation-items-project-fact-sheet-to-initiative)
  * [Developer Guide](https://help.sap.com/docs/leanix/ea/developer-guide)
    * [Basics](https://help.sap.com/docs/leanix/ea/basics)
      * [Choosing a Technology for Your Integration](https://help.sap.com/docs/leanix/ea/choosing-technology-for-your-integration)
      * [Authentication to SAP LeanIX Services](https://help.sap.com/docs/leanix/ea/authentication-to-sap-leanix-services)
        * [Technical Users](https://help.sap.com/docs/leanix/ea/technical-users)
        * [Configuring Authentication to SAP LeanIX APIs in Postman](https://help.sap.com/docs/leanix/ea/configuring-authentication-to-sap-leanix-apis-in-postman)
      * [Base URL](https://help.sap.com/docs/leanix/ea/base-url)
    * [Guides and Tutorials](https://help.sap.com/docs/leanix/ea/overview)
      * [Custom Reports](https://help.sap.com/docs/leanix/ea/custom-reports)
        * [Setting Up Your Custom Reports Project](https://help.sap.com/docs/leanix/ea/setting-up-your-custom-reports-project)
        * [Building Your First Custom Report](https://help.sap.com/docs/leanix/ea/building-your-first-custom-report)
        * [Filtering in Custom Reports](https://help.sap.com/docs/leanix/ea/filtering-in-custom-reports)
        * [Using GraphQL Queries with Custom Reports](https://help.sap.com/docs/leanix/ea/using-graphql-queries-with-custom-reports)
        * [Visualizing Data with Custom Reports](https://help.sap.com/docs/leanix/ea/visualizing-data-with-custom-reports)
        * [Creating a Custom Matrix Report](https://help.sap.com/docs/leanix/ea/creating-custom-matrix-report)
        * [Publishing Custom Reports on the SAP LeanIX Store](https://help.sap.com/docs/leanix/ea/publishing-custom-reports-on-sap-leanix-store)
          * [Review Criteria for Custom Reports](https://help.sap.com/docs/leanix/ea/review-criteria-custom-reports)
      * [Code-Based Automations](https://help.sap.com/docs/leanix/ea/code-based-automations)
        * [Calculating Risk Scores and Updating a Fact Sheet Based on Survey Responses](https://help.sap.com/docs/leanix/ea/calculating-risk-scores-and-updating-fact-sheet-based-on-survey-responses)
        * [Assigning Tags to Fact Sheets Based on Field Value Ranges](https://help.sap.com/docs/leanix/ea/assigning-tags-to-fact-sheets-based-on-custom-calculated-field)
        * [Managing Fact Sheet Tags Dynamically Based on Relation Changes](https://help.sap.com/docs/leanix/ea/managing-fact-sheet-tags-dynamically-based-on-relation-changes)
        * [Categorizing Applications Using the TIME Framework with Tags](https://help.sap.com/docs/leanix/ea/updating-tag-related-to-time-model)
      * [Importing and Exporting Data](https://help.sap.com/docs/leanix/ea/importing-and-exporting-data)
        * [Importing and Updating the Total Annual Costs of Applications](https://help.sap.com/docs/leanix/ea/importing-and-updating-total-annual-costs-of-applications)
        * [Exporting Workspace Snapshots](https://help.sap.com/docs/leanix/ea/exporting-workspace-snapshots)
      * [Bookmarks](https://help.sap.com/docs/leanix/ea/bookmarks)
        * [Retrieving a Diagram by ID](https://help.sap.com/docs/leanix/ea/retrieving-diagram-by-id)
      * [Updating User Permissions](https://help.sap.com/docs/leanix/ea/updating-user-permissions)
      * [Retrieving Survey Results](https://help.sap.com/docs/leanix/ea/retrieving-survey-results)
      * [Sending Alerts to Slack and Microsoft Teams](https://help.sap.com/docs/leanix/ea/sending-alerts-to-slack-and-microsoft-teams)
    * [SAP LeanIX APIs](https://help.sap.com/docs/leanix/ea/sap-leanix-apis)
      * [REST APIs](https://help.sap.com/docs/leanix/ea/rest-apis)
        * [REST APIs Overview](https://help.sap.com/docs/leanix/ea/rest-apis-overview)
      * [GraphQL API](https://help.sap.com/docs/leanix/ea/graphql-api)
        * [GraphQL Basics](https://help.sap.com/docs/leanix/ea/graphql-basics)
        * [Filtering in GraphQL](https://help.sap.com/docs/leanix/ea/filtering-in-graphql)
        * [Pagination in GraphQL](https://help.sap.com/docs/leanix/ea/pagination-in-graphql)
        * [Error Handling in GraphQL](https://help.sap.com/docs/leanix/ea/error-handling-in-graphql)
        * [Using GraphQL with Python](https://help.sap.com/docs/leanix/ea/using-graphql-with-python)
        * [Migrating from the Fact Sheets REST API to the GraphQL API](https://help.sap.com/docs/leanix/ea/migrating-from-fact-sheets-rest-api-to-graphql-api)
        * [Sample GraphQL Queries](https://help.sap.com/docs/leanix/ea/sample-queries)
          * [Retrieving Fact Sheets (GraphQL)](https://help.sap.com/docs/leanix/ea/retrieving-fact-sheets)
          * [Filtering Fact Sheets (GraphQL)](https://help.sap.com/docs/leanix/ea/filtering-fact-sheets)
          * [Creating a Fact Sheet (GraphQL)](https://help.sap.com/docs/leanix/ea/creating-fact-sheet)
          * [Updating a Fact Sheet (GraphQL)](https://help.sap.com/docs/leanix/ea/updating-fact-sheet)
          * [Managing Fact Sheet Relations (GraphQL)](https://help.sap.com/docs/leanix/ea/managing-relations-between-fact-sheets)
          * [Managing Fact Sheet Tags (GraphQL)](https://help.sap.com/docs/leanix/ea/managing-tags-on-fact-sheet)
          * [Managing Fact Sheet Resources (GraphQL)](https://help.sap.com/docs/leanix/ea/managing-resources-on-fact-sheet)
